"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const promisified_fs_tool_1 = __importDefault(require("./promisified-fs.tool"));
const logger_1 = require("../logger");
class PathsResolverTool {
    static async loadFilesToCompile() {
        const queries = await this.resolveFiles(this.QUERIES);
        const mutations = await this.resolveFiles(this.MUTATIONS);
        const entities = await this.resolveFiles(this.ENTITIES);
        const migrations = await this.resolveFiles(this.MIGRATIONS);
        const restResolvers = await this.resolveFiles(this.REST);
        return [...queries, ...mutations, ...entities, ...migrations, path_1.join(PathsResolverTool.RESOLVERS, 'resolvers.ts'), ...restResolvers];
    }
}
exports.default = PathsResolverTool;
PathsResolverTool.ROOT = process.env.LAUNCHER === 'true' ? `${process.cwd()}/packages/client-service` : process.cwd();
PathsResolverTool.DIST = path_1.join(PathsResolverTool.ROOT, 'dist');
PathsResolverTool.SRC = path_1.join(PathsResolverTool.ROOT, 'src');
PathsResolverTool.DATA = path_1.join(PathsResolverTool.SRC, 'data');
PathsResolverTool.ENTITIES = path_1.join(PathsResolverTool.DATA, 'entities');
PathsResolverTool.MIGRATIONS = path_1.join(PathsResolverTool.DATA, 'migrations');
PathsResolverTool.BUILD = path_1.join(PathsResolverTool.ROOT, '.build');
PathsResolverTool.SCHEMA = path_1.join(PathsResolverTool.SRC, 'schema.graphql');
PathsResolverTool.RESOLVERS = path_1.join(PathsResolverTool.SRC, 'resolvers');
PathsResolverTool.QUERIES = path_1.join(PathsResolverTool.RESOLVERS, 'queries');
PathsResolverTool.MUTATIONS = path_1.join(PathsResolverTool.RESOLVERS, 'mutations');
PathsResolverTool.REST = path_1.join(PathsResolverTool.SRC, 'rest');
PathsResolverTool.resolveFiles = async (path) => {
    try {
        await promisified_fs_tool_1.default.access(path);
        return promisified_fs_tool_1.default.readdir(path).then((data) => data
            .filter((file) => /.ts$/.test(file))
            .map((file) => path_1.join(path, file)));
    }
    catch (e) {
        logger_1.logger.log(`${path} is not available`);
        return [];
    }
};
//# sourceMappingURL=paths-resolver.tool.js.map